@@ -1,5 +1,5 @@
 #
-# $Id: Write.pm 360 2014-11-16 14:52:06Z gomor $
+# $Id: Write.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # file::write Brik
 #
@@ -11,18 +11,26 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 360 $',
-      tags => [ qw(unstable file) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          output => [ qw(file) ],
          append => [ qw(0|1) ],
          overwrite => [ qw(0|1) ],
          encoding => [ qw(utf8|ascii) ],
          fd => [ qw(file_descriptor) ],
+         unbuffered => [ qw(0|1) ],
+      },
+      attributes_default => {
+         append => 1,
+         overwrite => 0,
+         unbuffered => 0,
       },
       commands => {
-         open => [ ],
-         write => [ qw($data|$data_ref) ],
+         open => [ qw(file|OPTIONAL) ],
+         write => [ qw($data|$data_ref|$data_list) ],
          close => [ ],
       },
    };
@@ -34,9 +42,6 @@ sub brik_use_properties {
    # encoding: see `perldoc Encode::Supported' for other types
    return {
       attributes_default => {
-         output => $self->global->output || '/tmp/output.txt',
-         append => 1,
-         overwrite => 0,
          encoding => $self->global->encoding || 'utf8',
       },
    };
@@ -44,14 +49,17 @@ sub brik_use_properties {
 
 sub open {
    my $self = shift;
+   my ($output) = @_;
 
-   my $output = $self->output;
-   if (! defined($output)) {
-      return $self->log->error($self->brik_help_set('output'));
+   $output ||= $self->output;
+   $self->brik_help_run_undef_arg('open', $output) or return;
+
+   my $encoding = $self->encoding;
+   if ($encoding eq 'ascii') {
+      $encoding = '';
    }
 
    my $out;
-   my $encoding = $self->encoding;
    if ($self->append) {
       my $r = open($out, ">>$encoding", $output);
       if (! defined($r)) {
@@ -69,6 +77,15 @@ sub open {
       return $self->log->error($self->brik_help_set('overwrite'));
    }
 
+   if ($self->unbuffered) {
+      my $previous_default = select(STDOUT);
+      select($out);
+      $|++;
+      select($previous_default);          
+   }
+
+   $self->debug && $self->log->debug("open: fd [$out]");
+
    return $self->fd($out);
 }
 
@@ -87,18 +104,20 @@ sub write {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('write'));
-   }
+   my $fd = $self->fd;
+   $self->brik_help_run_undef_arg('open', $fd) or return;
+   $self->brik_help_run_undef_arg('write', $data) or return;
 
    $self->debug && $self->log->debug("write: data[$data]");
 
-   my $fd = $self->fd;
-   if (! defined($fd)) {
-      return $self->log->error($self->brik_help_run('open'));
+   if (ref($data) eq 'ARRAY') {
+      for my $this (@$data) {
+         print $fd $this."\n";
+      }
+   }
+   else {
+      ref($data) eq 'SCALAR' ? print $fd $$data : print $fd $data;
    }
-
-   ref($data) eq 'SCALAR' ? print $fd $$data : print $fd $data;
 
    return $data;
 }
@@ -113,7 +132,7 @@ Metabrik::File::Write - file::write Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
