@@ -1,5 +1,5 @@
 #
-# $Id: Dual.pm 360 2014-11-16 14:52:06Z gomor $
+# $Id: Dual.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # log::dual Brik
 #
@@ -11,20 +11,29 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 360 $',
-      tags => [ qw(log) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          level => [ qw(0|1|2|3) ],
-         output_file => [ qw(file) ],
+         output => [ qw(file) ],
+         time_prefix => [ qw(0|1) ],
+         text_prefix => [ qw(0|1) ],
          _fd => [ qw(file_descriptor) ],
       },
+      attributes_default => {
+         time_prefix => 0,
+         text_prefix => 0,
+         output => '/tmp/dual.log',
+      },
       commands => {
-         info => [ qw(string) ],
-         verbose => [ qw(string) ],
-         warning => [ qw(string) ],
-         error => [ qw(string) ],
-         fatal => [ qw(string) ],
-         debug => [ qw(string) ],
+         info => [ qw(string caller|OPTIONAL) ],
+         verbose => [ qw(string caller|OPTIONAL) ],
+         warning => [ qw(string caller|OPTIONAL) ],
+         error => [ qw(string caller|OPTIONAL) ],
+         fatal => [ qw(string caller|OPTIONAL) ],
+         debug => [ qw(string caller|OPTIONAL) ],
       },
       require_modules => {
          'Term::ANSIColor' => [ ],
@@ -39,7 +48,6 @@ sub brik_use_properties {
       attributes_default => {
          debug => $self->log->debug,
          level => $self->log->level,
-         output_file => $self->global->output,
       },
    };
 }
@@ -63,15 +71,11 @@ sub brik_preinit {
 }
 
 sub brik_init {
-   my $self = shift->SUPER::brik_init(
-      @_,
-   ) or return 1; # Init already done
+   my $self = shift;
 
-   print "DEBUG log::dual brik_init\n";
-
-   my $output_file = $self->output_file;
-   open(my $fd, '>', $output_file)
-      or return $self->log->error("brik_init: can't open output file [$output_file]: $!");
+   my $output = $self->output;
+   open(my $fd, '>', $output)
+      or return $self->log->error("brik_init: can't open output file [$output]: $!");
 
    # Makes the file handle unbuffered
    my $current = select;
@@ -81,7 +85,7 @@ sub brik_init {
 
    $self->_fd($fd);
 
-   return $self;
+   return $self->SUPER::brik_init;
 }
 
 sub _msg {
@@ -90,16 +94,18 @@ sub _msg {
 
    $msg ||= 'undef';
 
-   $brik =~ s/^metabrik::brik:://i;
+   $brik =~ s/^metabrik:://i;
 
    return lc($brik).": $msg\n";
 }
 
 sub warning {
    my $self = shift;
-   my ($msg) = @_;
+   my ($msg, $caller) = @_;
 
-   my $buffer = "[!] ".$self->_msg(my ($caller) = caller(), $msg);
+   my $prefix = $self->text_prefix ? "WARN " : "[!]";
+   my $time = $self->time_prefix ? localtime()." " : " ";
+   my $buffer = $time."$prefix ".$self->_msg(($caller) ||= caller(), $msg);
 
    my $fd = $self->_fd;
 
@@ -111,23 +117,29 @@ sub warning {
 
 sub error {
    my $self = shift;
-   my ($msg) = @_;
+   my ($msg, $caller) = @_;
 
-   my $buffer = "[-] ".$self->_msg(my ($caller) = caller(), $msg);
+   my $prefix = $self->text_prefix ? "ERROR" : "[-]";
+   my $time = $self->time_prefix ? localtime()." " : " ";
+   my $buffer = $time."$prefix ".$self->_msg(($caller) ||= caller(), $msg);
 
    my $fd = $self->_fd;
 
    print $fd $buffer;
    print $buffer;
 
-   return 0;
+   # Returning undef is my official way of stating an error occured:
+   # Number 0 is for stating a false condition occured, not not error.
+   return;
 }
 
 sub fatal {
    my $self = shift;
-   my ($msg) = @_;
+   my ($msg, $caller) = @_;
 
-   my $buffer = "[F] ".$self->_msg(my ($caller) = caller(), $msg);
+   my $prefix = $self->text_prefix ? "FATAL" : "[F]";
+   my $time = $self->time_prefix ? localtime()." " : " ";
+   my $buffer = $time."$prefix ".$self->_msg(($caller) ||= caller(), $msg);
 
    my $fd = $self->_fd;
 
@@ -137,13 +149,15 @@ sub fatal {
 
 sub info {
    my $self = shift;
-   my ($msg) = @_;
+   my ($msg, $caller) = @_;
 
-   return 0 unless $self->level > 0;
+   return 1 unless $self->level > 0;
 
    $msg ||= 'undef';
 
-   my $buffer = "[+] $msg\n";
+   my $prefix = $self->text_prefix ? "INFO " : "[+]";
+   my $time = $self->time_prefix ? localtime()." " : " ";
+   my $buffer = $time."$prefix $msg\n";
 
    my $fd = $self->_fd;
 
@@ -155,11 +169,13 @@ sub info {
 
 sub verbose {
    my $self = shift;
-   my ($msg) = @_;
+   my ($msg, $caller) = @_;
 
    return 1 unless $self->level > 1;
 
-   my $buffer = "[*] ".$self->_msg(my ($caller) = caller(), $msg);
+   my $prefix = $self->text_prefix ? "VERB " : "[*]";
+   my $time = $self->time_prefix ? localtime()." " : " ";
+   my $buffer = $time."$prefix ".$self->_msg(($caller) ||= caller(), $msg);
 
    my $fd = $self->_fd;
 
@@ -171,7 +187,7 @@ sub verbose {
 
 sub debug {
    my $self = shift;
-   my ($msg) = @_;
+   my ($msg, $caller) = @_;
 
    # We have a conflict between the method and the accessor,
    # we have to identify which one is accessed.
@@ -188,7 +204,9 @@ sub debug {
       else {
          return 1 unless $self->level > 2;
 
-         my $buffer = "[D] ".$self->_msg(my ($caller) = caller(), $msg);
+         my $prefix = $self->text_prefix ? "DEBUG" : "[D]";
+         my $time = $self->time_prefix ? localtime()." " : " ";
+         my $buffer = $time."$prefix ".$self->_msg(($caller) ||= caller(), $msg);
 
          my $fd = $self->_fd;
 
@@ -222,7 +240,7 @@ Metabrik::Log::Dual - log::dual Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
