@@ -1,5 +1,5 @@
 #
-# $Id: Compress.pm 360 2014-11-16 14:52:06Z gomor $
+# $Id: Compress.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # string::gzip Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 360 $',
-      tags => [ qw(unstable gzip gunzip uncompress compress) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable gzip gunzip unzip uncompress) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          data => [ qw($data) ],
          memory_limit => [ qw(integer) ],
@@ -34,9 +36,7 @@ sub gunzip {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('gunzip'));
-   }
+   $self->brik_help_run_undef_arg('gunzip', $data) or return;
 
    $self->debug && $self->log->debug("gunzip: length[".length($data)."]");
 
@@ -56,9 +56,7 @@ sub gzip {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('gzip'));
-   }
+   $self->brik_help_run_undef_arg('gzip', $data) or return;
 
    my $gzipped = Gzip::Faster::gzip($data)
       or return $self->log->error("gzip: error");
@@ -76,7 +74,7 @@ Metabrik::String::Compress - string::compress Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
